@@ -119,7 +119,7 @@ Control::Control(const QString& ruleFile, SimRules *sr, QObject *parent)
         << SIGNAL(command(QString))
         << SIGNAL(variableChanged(QString,QString))
         << SIGNAL(switchTo(QString))
-        << SIGNAL(startIncomingCall(QString, QString));
+        << SIGNAL(startIncomingCall(QString, QString, QString));
 
     foreach (QByteArray sig, proxySignals)
         connect(widget, sig, this, sig);
@@ -282,15 +282,19 @@ void ControlWidget::sendSMSDatagram()
 void ControlWidget::sendCall()
 {
     QString number;
+    QString calledNumber;
     QString name;
 
     if (ui->cbCaller->isChecked())
         number = ui->leCaller->text();
 
+    if (ui->cbCalledLine->isChecked())
+        calledNumber = ui->leCalledLine->text();
+
     if (ui->cbCallerName->isChecked())
         name = ui->leCallerName->text();
 
-    emit startIncomingCall( number, name );
+    emit startIncomingCall( number, calledNumber, name );
 }
 
 void ControlWidget::handleFromData( const QString& cmd )
@@ -457,8 +461,7 @@ void ControlWidget::simInsertRemove()
 
 void ControlWidget::handleNewApp()
 {
-    ui->lblApplicationName->setText( "Current application: " +
-            p->getSimAppName() );
+    ui->cbSimApps->insertItems( 0, p->getSimAppsNameList() );
 }
 
 void Control::handleNewApp()
@@ -468,7 +471,8 @@ void Control::handleNewApp()
 
 void ControlWidget::simAppStart()
 {
-    p->simAppStart();
+    if ( ui->cbSimApps->currentIndex() >= 0 )
+        p->simAppStart( ui->cbSimApps->currentIndex() );
 }
 
 void ControlWidget::simAppAbort()
